@@ -119,7 +119,7 @@ find_in_debug_path (const char *filename, const char *debug_filename)
 	}
 
 	for (i = 0; i < N_TRIES; i++)
-		g_free (tries [N_TRIES]);
+		g_free (tries [i]);
 
 	return result;
 }
